import requests


class Light(object):
    """Class for creating and manipulating lights."""
    def __init__(self, bridge, id):
        """Constructor. """
        self.bridge = bridge
        self.id = id
        self.url = bridge.url() + '/lights/' + str(id)

    def __repr__(self):
        """Representation of the Light object."""
        return "Light(bridgeobject, {})".format(self.id)

    def __str__(self):
        """Representation of the Light object."""
        return 'Philips Hue light with id: ' + str(self.id)

    def turnon(self):
        """Turns this light on and returns the response."""
        url = self.url + '/state'
        body = {}
        body['on'] = True
        response = requests.put(url, json=body).json()
        return response

    def turnoff(self):
        """Turns this light off and returns the response."""
        url = self.url + '/state'
        body = {}
        body['on'] = False
        response = requests.put(url, json=body).json()
        return response

    def effect(self, effect):
        """Set the effect of the light and return the response.

        Keyword argument:
        effect - none|colorloop
        """
        valideffects = ['none', 'colorloop']
        if effect in valideffects:
            url = self.url + '/state'
            body = {}
            body['effect'] = effect
            response = requests.put(url, json=body).json()
        else:
            response = [{'error': {'type': 'not a valid effect'}}]
        return response

    def bri(self, bri):
        """Set the brightness of a light and return the response.

        Keyword argument:
        bri - integer on a scale from 1 to 254
        """
        if bri in range(0, 255):
            url = self.url + '/state'
            body = {}
            body['bri'] = bri
            response = requests.put(url, json=body).json()
        else:
            response = [{'error': {'type': 'bri not in range 1 - 254'}}]
        return response

    def rgb(self, r, g, b):
        """Convert rgb to xy, set the lightcolor using xy values and
        return the repsonse.

        Keyword arguments:
        r - red value (0-255)
        g - green value (0-255)
        b - blue value (0-255)
        """
        rgb = [r, g, b]
        url = self.url + '/state'
        body = {}
        for i in range(len(rgb)):
            rgb[i] = float(rgb[i]) / 255
            if rgb[i] > 0.04045:
                rgb[i] = ((rgb[i] + 0.055) / 1.055) ** 2.4
            else:
                rgb[i] = rgb[i] / 12.92
        x = rgb[0] * 0.664511 + rgb[1] * 0.154324 + rgb[2] * 0.162028
        y = rgb[0] * 0.283881 + rgb[1] * 0.668433 + rgb[2] * 0.047685
        z = rgb[0] * 0.000088 + rgb[1] * 0.072310 + rgb[2] * 0.986039
        if x + y + z != 0:
            x = round(x / (x + y + z), 4)
            y = round(y / (x + y + z), 4)
        body['xy'] = [x, y]
        response = requests.put(url, json=body).json()
        return response



import requests


class Bridge(object):
    """This class creates objects of the hue bridge type. If a username
    is not provided the only thing to do is to use the createuser
    method.

    Keyword arguments:
    ipadress - ipaddress of the Philips Hue Bridge
    username - valid Philips Hue Bridge username
    """
    def __init__(self, ipaddress, username=None):
        """Constructor. """
        self.ipaddress = ipaddress
        self.username = username

    def __repr__(self):
        """Representation of the Bridge object."""
        return "Bridge('{}', '{}')".format(self.ipaddress, self.username)

    def __str__(self):
        """Representation of the Bridge object."""
        return 'Bridge with ip-address: {}'.format(self.ipaddress)

    def url(self):
        """Constucts and returns the url of the bridges REST-API."""
        if (self.username is None):
            url = 'http://' + self.ipaddress + '/api/'
        else:
            url = 'http://' + self.ipaddress + '/api/' + self.username
        return url

    def createuser(self, devtype):
        """Creates a new username on the bridge.

        Keyword argument:
        devtype - device type that will use this username.
        """
        url = self.url()
        body = {}
        body['devicetype'] = devtype
        response = requests.post(url, json=body).json()
        return response

    def deleteuser(self, user2bedeleted):
        """Deletes a user from the bridge.

        Keyword argument:
        user2bedeleted - the username that should be deleted.
        """
        url = self.url() + '/config/whitelist/' + user2bedeleted
        response = requests.delete(url).json()
        return response

    def listusers(self):
        """Get the username's from the bridge and returns a list. """
        users = []
        url = self.url() + '/config'
        response = requests.get(url).json()
        whitelist = response['whitelist']
        for key in whitelist:
            users.append(whitelist[key]['name'])
        return users

    def getgroupids(self):
        """Get all defined group id's and return a list of group id's"""
        url = self.url() + '/groups'
        gids = list(requests.get(url).json().keys())
        return gids

    def getlightids(self):
        """Get all light id's and return a list of light id's"""
        url = self.url() + '/lights'
        lightids = list(requests.get(url).json().keys())
        return lightids



from setuptools import setup
from pyphihue import __author__
from pyphihue import __version__


VER = "{}.{}.{}".format(*__version__)
URL = 'https://gitlab.com/pyphihue/pyphihue'

setup(name='pyphihue',
      packages=['pyphihue'],
      version=VER,
      description='A library to interface with Philips Hue',
      author=__author__,
      author_email='pydevpat@gmail.com',
      url=URL,
      download_url='{}/repository/archive.tar.gz?ref=master'.format(URL),
      license='MIT',
      keywords='Philips Hue API-wrapper',
      install_requires=[
          'requests',
      ],
      classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Home Automation',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6'
      ],
      )
